==> ckb-next_0.4.2+dfsg.1.orig.tar.xz: ckb-next-0.4.2/README.md <==
# ckb-next: RGB Driver for Linux and macOS

<a target="_blank" href="http://webchat.freenode.net?channels=%23ckb-next&uio=d4"><img src="https://cloud.githubusercontent.com/assets/493242/14886493/5c660ea2-0d51-11e6-8249-502e6c71e9f2.png" height = "20" /></a>

**ckb-next** is an open-source driver for Corsair keyboards and mice. It aims to bring the features of Corsair's proprietary CUE software to the Linux and Mac operating systems. This project is currently a work in progress, but it already supports much of the same functionality, including full RGB animations. More features are coming soon. Testing and bug reports are appreciated!

> __DISCLAIMER__: ckb-next is not an official Corsair product. It is licensed under the GNU General Public License (version 2) in the hope that it will be useful, but with NO WARRANTY of any kind.

![Screenshot](https://i.imgur.com/zMK9jOP.png)

Major features:

- Control multiple devices independently
- United States and European keyboard layouts
- Customizable key bindings
- Per-key lighting and animation
- Reactive lighting
- Multiple profiles/modes with hardware save function
- Adjustable mouse DPI with ability to change DPI on button press

### General information

Most of the information can be found on [ckb-next wiki pages](https://github.com/ckb-next/ckb-next/wiki).

[Supported keyboards and mice](https://github.com/ckb-next/ckb-next/wiki/Supported-Hardware).

[Linux Installation](https://github.com/ckb-next/ckb-next/wiki/Linux-Installation).

[macOS Installation](https://github.com/ckb-next/ckb-next/wiki/macOS-Installation).

[Troubleshooting](https://github.com/ckb-next/ckb-next/wiki/Troubleshooting).

[Known Issues](https://github.com/ckb-next/ckb-next/wiki/Known-issues).

[Contributing](https://github.com/ckb-next/ckb-next/wiki/Contributing).

### Contact

Maintainers reserve the rights to modify and remove issues, pull requests and comments therein, that are denunciating, off-topic, harmful, hateful and overall inappropriate.
Please be appreciative, humble and kind to each other.

* IRC chat: `#ckb-next` channel at [chat.freenode.net](http://webchat.freenode.net?channels=%23ckb-next&uio=d4)
* Mailing list: [ckb-next@googlegroups.com](https://groups.google.com/forum/#!forum/ckb-next)
* [GitHub Issues](https://github.com/ckb-next/ckb-next/issues)

==> ckb-next_0.4.3+dfsg.1.orig.tar.xz: ckb-next-0.4.3/README.md <==
# ckb-next: RGB Driver for Linux and macOS

<a target="_blank" href="http://webchat.freenode.net?channels=%23ckb-next&uio=d4"><img src="https://cloud.githubusercontent.com/assets/493242/14886493/5c660ea2-0d51-11e6-8249-502e6c71e9f2.png" height = "20" /></a>

**ckb-next** is an open-source driver for Corsair keyboards and mice. It aims to bring the features of Corsair's proprietary CUE software to Linux operating systems. This project is currently a work in progress, but it already supports much of the same functionality, including full RGB animations. More features are coming soon. Testing and bug reports are appreciated!

> __DISCLAIMER__: ckb-next is not an official Corsair product. It is licensed under the GNU General Public License (version 2) in the hope that it will be useful, but with NO WARRANTY of any kind.

![Screenshot](https://i.imgur.com/zMK9jOP.png)

Major features:

- Control multiple devices independently
- United States and European keyboard layouts
- Customizable key bindings
- Per-key lighting and animation
- Reactive lighting
- Multiple profiles/modes with hardware save function
- Adjustable mouse DPI with ability to change DPI on button press

### Important information regarding macOS
macOS is no longer officially supported. For more information, please refer to [issue #660](https://github.com/ckb-next/ckb-next/issues/660).

### General information

Most of the information can be found on [ckb-next wiki pages](https://github.com/ckb-next/ckb-next/wiki).

[Supported devices](https://github.com/ckb-next/ckb-next/wiki/Supported-Hardware).

[Linux Installation](https://github.com/ckb-next/ckb-next/wiki/Linux-Installation).

[Troubleshooting](https://github.com/ckb-next/ckb-next/wiki/Troubleshooting).

[Known Issues](https://github.com/ckb-next/ckb-next/wiki/Known-issues).

[Contributing](https://github.com/ckb-next/ckb-next/wiki/Contributing).

### Contact

Maintainers reserve the rights to modify and remove issues, pull requests and comments therein, that are denunciating, off-topic, harmful, hateful and overall inappropriate.
Please be appreciative, humble and kind to each other.

* IRC chat: `#ckb-next` channel at [chat.freenode.net](http://webchat.freenode.net?channels=%23ckb-next&uio=d4)
* Mailing list: [ckb-next@googlegroups.com](https://groups.google.com/forum/#!forum/ckb-next)
* [GitHub Issues](https://github.com/ckb-next/ckb-next/issues)
